| Title: | Displays Palette of 5 Colors |
|---|---|
| Description: | Displays palette of 5 colors based on photos depicting the unique and vibrant culture of Punjab in Northern India. Since Punjab translates to ``Land of 5 Rivers'' there are 5 colors per palette. If users need more than 5 colors, they can merge 2 to 3 palettes to create their own color-combination, or they can cherry-pick their own custom colors. Users can view up to 3 palettes together. Users can also list all the palette choices. And last but not least, users can see the photo that inspired a particular palette. |
| Authors: | Sonia Ahluwalia [aut, cre] |
| Maintainer: | Sonia Ahluwalia <[email protected]> |
| License: | GPL-2 |
| Version: | 2.3.4 |
| Built: | 2026-05-28 09:41:27 UTC |
| Source: | https://github.com/cran/RanglaPunjab |
This function allows user to cherry pick colors from 2 to 3 palettes
CherryPickPalette(name, name2 = NULL, name3 = NULL, ...)CherryPickPalette(name, name2 = NULL, name3 = NULL, ...)
name |
Name of 1st palette |
name2 |
Name of 2nd palette |
name3 |
Name of 3nd (optional) palette |
... |
Numeric, complex, or logical vectors |
user-defined palette of colors
CherryPickPalette("GoldenTemple","AmritsariPedeWaliLassi") CherryPickPalette("BiryaniRice","Kulfi","Haveli2")CherryPickPalette("GoldenTemple","AmritsariPedeWaliLassi") CherryPickPalette("BiryaniRice","Kulfi","Haveli2")
This function returns list of all palettes
ListPalette()ListPalette()
List of palettes
ListPalette()ListPalette()
This function takes 2 or 3 palettes and returns a palette of 10 or 15 colors (in the unlikely event there are duplicates, then return less than 10 or 15)
MergePalette(name, name2 = NULL, name3 = NULL, ...)MergePalette(name, name2 = NULL, name3 = NULL, ...)
name |
Name of 1st palette |
name2 |
Name of 2nd palette |
name3 |
Name of 3nd (optional) palette |
... |
Numeric, complex, or logical vectors |
Vector of 10 or 15 color values (in the unlikely event there are duplicates, then return less than 10 or 15 colors)
MergePalette("AmritsariKulcha", "Phulkari2") MergePalette("Gidha", "Jutti2") MergePalette("FieldsOfPunjab","GoldenTemple2","Jutti3")MergePalette("AmritsariKulcha", "Phulkari2") MergePalette("Gidha", "Jutti2") MergePalette("FieldsOfPunjab","GoldenTemple2","Jutti3")
This function paints an image of up to 3 palettes
PaintPalette(name = NULL, name2 = NULL, name3 = NULL, ...)PaintPalette(name = NULL, name2 = NULL, name3 = NULL, ...)
name |
Name of 1st palette |
name2 |
Name of 2nd (optional) palette |
name3 |
Name of 3rd (optional) palette |
... |
Numeric, complex, or logical vectors |
image of colors and description
PaintPalette("Pindh") PaintPalette("FieldsOfPunjab","Jutti") PaintPalette("FieldsOfPunjab","Jutti","Paranda")PaintPalette("Pindh") PaintPalette("FieldsOfPunjab","Jutti") PaintPalette("FieldsOfPunjab","Jutti","Paranda")
This function returns a palette of 5 colors
RanglaPunjab(name = NULL, ...)RanglaPunjab(name = NULL, ...)
name |
Palette name |
... |
Numeric, complex, or logical vectors |
Vector of 5 color values
RanglaPunjab("GoldenTemple") RanglaPunjab("SohniMahiwal") RanglaPunjab("Teej")RanglaPunjab("GoldenTemple") RanglaPunjab("SohniMahiwal") RanglaPunjab("Teej")
This function shows photo that inspired a palette
ShowPalettePhoto(name = NULL, ...)ShowPalettePhoto(name = NULL, ...)
name |
palette name |
... |
Numeric, complex, or logical vectors |
image of reference photo with palette
ShowPalettePhoto("GoldenTemple") ShowPalettePhoto("Kulfi") ShowPalettePhoto("AmritsariPedeWaliLassi")ShowPalettePhoto("GoldenTemple") ShowPalettePhoto("Kulfi") ShowPalettePhoto("AmritsariPedeWaliLassi")